========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/kolla-kubernetes.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on


==============
Kolla Overview
==============

The Kolla project is a member of the OpenStack `Big Tent
Governance <http://governance.openstack.org/reference/projects/index.html>`__.

Kolla's mission statement is:

::

    To provide production-ready containers and deployment tools for operating
    OpenStack clouds.

================
kolla-kubernetes
================

The kolla-kubernetes deliverable deploys OpenStack on top of Kubernetes.
This work is experimental at this time.  A 1.0.0 version or later signals
this work is ready for evaluation.

The kolla-kubernetes Repository
===============================

The kolla-kubernetes repository is one of three deliverables of the
OpenStack Kolla project.  The three deliverables that make up the Kolla
project are:

===============   =====================================================
Deliverable       Repository
===============   =====================================================
kolla             https://git.openstack.org/openstack/kolla
kolla-ansible     https://git.openstack.org/openstack/kolla-ansible
kolla-kubernetes  https://git.openstack.org/openstack/kolla-kubernetes

The kolla deliverable maintains container images and container build tools.

The kolla-ansible deliverable maintains an Ansible deployment for Kolla
containers on bare metal.

THe kolla-kubernetes deliverable maintains a cloud-native implementation
of deployment of OpenStack on Kubernetes.

Getting Involved
================

Need a feature? Find a bug? Let us know! Contributions are much
appreciated and should follow the standard `Gerrit
workflow <http://docs.openstack.org/infra/manual/developers.html>`__.

-  We communicate using the #openstack-kolla irc channel.
-  File bugs, blueprints, track releases, etc on
   `Launchpad <https://launchpad.net/kolla-kubernetes>`__.
-  Attend weekly
   `meetings <https://wiki.openstack.org/wiki/Meetings/Kolla>`__.
-  Contribute `code <https://git.openstack.org/openstack/kolla-kubernetes>`__.

General Information
===================

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/kolla-kubernetes
* Source: http://git.openstack.org/cgit/openstack/kolla-kubernetes
* Bugs: http://bugs.launchpad.net/kolla-kubernetes

Notices
=======

Docker and the Docker logo are trademarks or registered trademarks of
Docker, Inc. in the United States and/or other countries. Docker, Inc.
and other parties may also have trademark rights in other terms used herein.
